import { isToday, isAfter, parse } from "date-fns";
import { nb } from "date-fns/locale";
import { toZonedTime, format } from "date-fns-tz";

const timeZone = "Europe/Oslo";

export const compactDateTimeFormat = "dd.MM.yyyy 'kl.' HH:mm";
export const compactDateFormat = "dd.MM.yyyy";

export function toLocalTime(date: Date | string | number) {
  return toZonedTime(date, timeZone);
}

export function formatDate(date: Date | string | number, formatStr: string) {
  return format(toLocalTime(date), formatStr, { timeZone, locale: nb });
}

export function formatYearMonth(yearMonth: string) {
  // full name of month if year is current year, otherwise name of month + year
  const parsed = parse(yearMonth, "yyyy-MM", new Date());
  if (parsed.getFullYear === new Date().getFullYear) {
    return formatDate(parsed, "MMMM");
  }
  return formatDate(parsed, "MMMM yyyy");
}

export function formatExtendedDateTime(
  date: Date | string | number,
  dateOnly: boolean = false,
  alwaysIncludeYear: boolean = false
) {
  // wide date with weekday and month name
  // year included if not current year
  const parsed = toLocalTime(date);
  const timePart = dateOnly ? "" : " 'kl.' HH:mm";
  const isCurrentYear = parsed.getFullYear === new Date().getFullYear;
  const yearPart = isCurrentYear && !alwaysIncludeYear ? "" : " yyyy";
  return formatDate(parsed, `EEEE d. MMMM${yearPart}${timePart}`);
}

export function isTodayOrFuture(
  date: Date | string | number,
  timeZone = "UTC"
) {
  const now = new Date();
  const zonedNow = toZonedTime(now, timeZone);
  const zonedDate = toLocalTime(date);
  return isToday(zonedDate) || isAfter(zonedDate, zonedNow);
}
